@@ -405,7 +405,7 @@ add_new_sources (ExchangeAccount *account)
 	GPtrArray *exchange_folders;
 
 	exchange_folders = exchange_account_get_folders (account);
-        if (exchange_folders && exchange_folders->len > 0) {
+	if (exchange_folders && exchange_folders->len > 0) {
 		gint i;
 		const gchar *folder_type;
 		const gchar *folder_name;
@@ -449,7 +449,7 @@ add_new_sources (ExchangeAccount *account)
 							folder_name, folder_uri);
 			} /* End hierarchy type check */
 		} /* End for loop */
-        } /* End check for a list of folders */
+	} /* End check for a list of folders */
 }
 
 static void
@@ -458,7 +458,7 @@ add_sources (ExchangeAccount *account)
 	GPtrArray *exchange_folders;
 
 	exchange_folders = exchange_account_get_folders (account);
-        if (exchange_folders && exchange_folders->len > 0) {
+	if (exchange_folders && exchange_folders->len > 0) {
 		gint i;
 		const gchar *folder_type;
 		EFolder *folder;
@@ -499,7 +499,7 @@ add_sources (ExchangeAccount *account)
 		add_account_esources (account, folders);
 		g_slist_foreach (folders, (GFunc) g_free, NULL);
 		g_slist_free (folders);
-        }
+	}
 }
 #endif
 
@@ -512,7 +512,6 @@ remove_account_esource (ExchangeAccount *account,
 	GSList *groups;
 	GSList *sources;
 	GSList *ids, *node_to_be_deleted;
-	gboolean found_group;
 	const gchar *source_uid;
 	GConfClient *client;
 	ESourceList *source_list = NULL;
@@ -532,14 +531,13 @@ remove_account_esource (ExchangeAccount *account,
 							CONF_KEY_TASKS);
 
 	groups = e_source_list_peek_groups (source_list);
-	found_group = FALSE;
 
-	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
-                    &&
-                    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
+		    &&
+		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			sources = e_source_group_peek_sources (group);
 
 			for (; sources != NULL; sources = g_slist_next (sources)) {
@@ -593,7 +591,7 @@ remove_account_esource (ExchangeAccount *account,
 			}
 			e_source_list_remove_group (source_list, group);
 			e_source_list_sync (source_list, NULL);
-			found_group = TRUE;
+			break;
 		}
 	}
 	g_object_unref (source_list);
@@ -649,7 +647,6 @@ change_passwd_cb (GtkWidget *button, ExchangeAccount *account)
 static void
 display_passwd_expiry_message (gint max_passwd_age, ExchangeAccount *account)
 {
-	GtkResponseType response;
 	GtkWidget *passwd_exp_dialog;
 	GtkWidget *dialog_vbox1;
 	GtkWidget *dialog_action_area1;
@@ -702,7 +699,7 @@ display_passwd_expiry_message (gint max_passwd_age, ExchangeAccount *account)
 			  G_CALLBACK (change_passwd_cb),
 			  account);
 #endif
-	response = gtk_dialog_run (GTK_DIALOG (passwd_exp_dialog));
+	gtk_dialog_run (GTK_DIALOG (passwd_exp_dialog));
 
 	gtk_widget_destroy (passwd_exp_dialog);
 	g_free (passwd_expiry_msg);
@@ -820,14 +817,12 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 #endif
 	gboolean oldremember, remember = FALSE;
 	CamelURL *camel_url;
-	const gchar *remember_password;
 
 	g_return_val_if_fail (EXCHANGE_IS_CONFIG_LISTENER (ex_conf_listener), EXCHANGE_ACCOUNT_CONFIG_ERROR);
 	priv = ex_conf_listener->priv;
 
 	camel_url = camel_url_new (priv->configured_uri, NULL);
 	key = camel_url_to_string (camel_url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
-	remember_password = camel_url_get_param (camel_url, "save-passwd");
 	password = e_passwords_get_password ("Exchange", key);
 	if (!password) {
 		oldremember = remember = exchange_account_is_save_password (account);
@@ -837,7 +832,6 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 						     &remember, NULL);
 		if (remember != oldremember) {
 			exchange_account_set_save_password (account, remember);
-			camel_url_set_param (camel_url, "save-passwd", remember? "true" : "false");
 			url_string = camel_url_to_string (camel_url, 0);
 			e_account_set_string (ex_conf_listener->priv->configured_account, E_ACCOUNT_SOURCE_URL, url_string);
 			e_account_set_string (ex_conf_listener->priv->configured_account, E_ACCOUNT_TRANSPORT_URL, url_string);
@@ -847,8 +841,7 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 			g_free (url_string);
 		}
 		g_free (title);
-	}
-	else if (remember_password && !g_ascii_strcasecmp (remember_password, "false")) {
+	} else if (!exchange_account_is_save_password (account)) {
 		/* get_password returns the password cached but user has not
 		 * selected remember password option, forget this password
 		 * whis is stored temporarily by e2k_validate_user(), to avoid
@@ -1352,16 +1345,15 @@ exchange_add_autocompletion_folders (GConfClient *gc_client, ExchangeAccount *ac
 	ESourceList *sl=NULL;
 	ESource *source;
 	GSList *groups;
-	gboolean found_group=FALSE;
 
 	sl = e_source_list_new_for_gconf (gc_client, CONF_KEY_CONTACTS);
 	groups = e_source_list_peek_groups (sl);
 
-	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
-                    &&
+		    &&
 		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			GSList *sources = e_source_group_peek_sources (group);
 
@@ -1378,7 +1370,7 @@ exchange_add_autocompletion_folders (GConfClient *gc_client, ExchangeAccount *ac
 					break;
 				}
 			}
-			found_group = TRUE;
+			break;
 		}
 	}
 
@@ -1452,7 +1444,6 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gco
 	GSList *groups;
 	GSList *sources;
 	GSList *ids, *node_to_be_deleted;
-	gboolean found_group;
 	const gchar *source_uid;
 	GConfClient *client;
 	ESourceList *source_list = NULL;
@@ -1472,14 +1463,13 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gco
 	source_list = e_source_list_new_for_gconf ( client, gconf_key);
 
 	groups = e_source_list_peek_groups (source_list);
-	found_group = FALSE;
 
-	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
-                    &&
-                    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
+		    &&
+		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			sources = e_source_group_peek_sources (group);
 
 			for (; sources != NULL; sources = g_slist_next (sources)) {
@@ -1510,8 +1500,8 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gco
 					g_slist_free (ids);
 				}
 			}
-			found_group = TRUE;
 			e_source_list_sync (source_list, NULL);
+			break;
 		}
 	}
 
